@@ -18,6 +18,40 @@ class UnexpectedPrompt(Exception):
     def __init__(self):
         super(UnexpectedStateTransition, self)
 
+class TeeStdoutFile(object):
+    def __init__(self, log_file="", filemode="w", log_screen=False):
+        self.log_file = os.path.expanduser(log_file)
+        self.filemode = filemode
+        self.log_screen = log_screen
+        self.stdout = sys.stdout
+
+        try:
+            assert os.path.isfile(self.log_file) is False
+        except AssertionError:
+            raise ValueError("Cannot overwrite existing log_file={}".format(
+                self.log_file))
+            sys.exit(1)
+
+        self.fh = open(self.log_file, self.filemode)
+
+    def __del__(self):
+        sys.stdout = self.stdout
+        try:
+            self.fh.close()
+        except AttributeError:
+            # We hit this if self.fh was never opened such as existing log_file
+            pass
+
+    def write(self, line):
+        self.fh.write(line)
+        self.stdout.write(line)
+
+    def flush(self):
+        self.fh.flush()
+
+    def close(self):
+        self.fh.close()
+
 
 class Account(object):
     def __init__(self, user, passwd="", priv_passwd=""):
@@ -33,7 +67,7 @@ class Shell(transitions.Machine):
     def __init__(self, host='', credentials=(), protocols=({'proto': 'ssh',
         'port': 22}, {'proto': 'telnet', 'port': 23}), auto_priv_mode=True,
         log_screen=False, log_file='', debug=False, command_timeout=30, 
-        login_timeout=10, relogin_delay=120, encoding='utf-8', 
+        login_timeout=10, relogin_delay=120, encoding='utf-8',
         login_attempts=3):
 
         STATES = ('INIT_SESSION', 'SELECT_PROTOCOL', 
@@ -379,17 +413,16 @@ class Shell(transitions.Machine):
             time.sleep(70)
 
         # log to screen if requested
-        if (self.log_screen is True) and (self.log_file==''):
-            self.child.log_file = sys.stdout
+        if self.log_screen and self.log_file=="":
+            self.child.logfile = sys.stdout
 
-        elif (self.log_screen is False) and (self.log_file!=''):
-            error_str = "Cannot overwrite existing file: {}".format(
-                self.log_file)
-            assert not os.path.isfile(self.log_file), error_str
-            self.child.log_file = open(self.log_file, 'w')
+        elif (self.log_screen is False) and self.log_file!="":
+            self.child.logfile = open(self.log_file, 'w')
 
-        elif (self.log_screen is True) and (self.log_file!=''):
-            raise ValueError("log_screen and log_file are mutually exclusive options")
+        elif (self.log_screen is True) and self.log_file!="":
+            self.child.logfile = TeeStdoutFile(log_file=self.log_file,
+            log_screen=self.log_screen)
+            #raise ValueError("Cannot use log_screen and log_file")
 
         try:
             index = self.child.expect(self.base_prompt_regex, 
